/* 
   - The contents of this file are subject to the Mozilla Public
   - License Version 1.1 (the "License"); you may not use this file
   - except in compliance with the License. You may obtain a copy of
   - the License at http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS
   - IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
   - implied. See the License for the specific language governing
   - rights and limitations under the License.
   -
   - The Original Code is this file as it was released on
   - April 1, 2001.
   -
   - The Initial Developer of the Original Code is HJ van Rantwijk.
   - Portions created by HJ van Rantwijk are Copyright (C) 2001-2004
   - HJ van Rantwijk.  All Rights Reserved.
   -
   - Contributor(s):
   -  HJ van Rantwijk <bugs4hj@netscape.net> (Original Author)
   -  David Perry <d.perry@utoronto.ca> (limited to first 2 functions)
   -
*/

////////////////////////////////////////////////////////////////////////////////
function defineShortURL(aURI)
{
  try {
    var i = aURI.indexOf(":");
  } 
  catch(ex) {
    return aURI;
  }
  if (i != -1) {
    while(!isAlphaNum(aURI[i]))
      i++;
    return aURI.substring(i, aURI.length);
  }
  return aURI;
}
////////////////////////////////////////////////////////////////////////////////
function isAlphaNum(mixedCase)
{
  var allCaps = mixedCase.toUpperCase();
  for (var i = allCaps.length - 1; i >= 0; i--) {
    var c = allCaps.charAt(i);
    if ((c < 'A' || c > 'Z') && (c < '0' || c > '9') && (c!='_'))
      return false;
  }
  return true;
}
////////////////////////////////////////////////////////////////////////////////
function getLocationFromClipboard()
{
  var URL = null;
  var clipboard = Components.classes["@mozilla.org/widget/clipboard;1"].getService(Components.interfaces.nsIClipboard);
  var trans = Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);
  var ioService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);

  try {
    trans.addDataFlavor("text/unicode");
    clipboard.getData(trans, clipboard.kGlobalClipboard);

    var data = {};
    var dataLen = {};
    trans.getTransferData("text/unicode", data, dataLen);

    if (data) {
      data = data.value.QueryInterface(Components.interfaces.nsISupportsString);
      data = data.data.substring(0, dataLen.value / 2);
      // Convert clipboard data to URL
      try {
        var URI = ioService.newURI(data, null, null);
        URL = URI.spec;
      } catch(ex) {
        alert(mzGetTextFromBundle("noValidClipboardURL"));
      }
    }
    else {
      alert(mzGetTextFromBundle("noClipboardData"));
    }
  } catch (ex) {
    alert(mzGetTextFromBundle("clipboardReadError"));
  }
  return URL;
}
////////////////////////////////////////////////////////////////////////////////
function displayVersion()
{
  var mVersion = getBrowser().mVersion;
  var mVersionRev = getBrowser().mVersionRev;

  window.openDialog("chrome://multiviews/content/multiviewsAbout.xul", "multiviewsAbout", 
                    "chrome, dialog, dependent",(mVersion+mVersionRev),loadURI);
}
////////////////////////////////////////////////////////////////////////////////
// This function collects version/revision info and builds the following URL:
// http://multizilla.mozdev.org/update.html?version=1.6.0.1&revision=e&gb-version=1.4&gb-revision=c
////////////////////////////////////////////////////////////////////////////////
function doCheck4Updates()
{
  var URL = "http://multizilla.mozdev.org/update.html?version=";
  var mzVersionInfo = gBrowser.mVersion + "&revision=" + gBrowser.mVersionRev;
  var gbVersionInfo = "";

  if (mzToolbox.mToolboxActivated) { // GoogleBox installed?
    var googleBox = document.getElementById("internalToolBox");
    // Pre GoogleBox v1.4a versions had no version info, that's why we check for 'undefined'
    var googleBoxVersion = (googleBox.mVersion == undefined) ? 0 : googleBox.mVersion;
    var googleBoxRevision = (googleBox.mVersionRev == undefined) ? "" : googleBox.mVersionRev;
    gbVersionInfo = "&gb-version=" + googleBoxVersion + "&gb-revision=" + googleBoxRevision;
  }
  gBrowser.selectedTab = gBrowser.addOrGetTab(URL + mzVersionInfo + gbVersionInfo, null);
}
////////////////////////////////////////////////////////////////////////////////
function validateThisPage(aURL)
{
  if (aURL) {
    var IOService = Components.classes["@mozilla.org/network/io-service;1"]
                              .getService(Components.interfaces.nsIIOService);
    if (!IOService)
       return;
    var scheme = "";

    try {
      scheme = IOService.extractScheme(aURL, {schemeStartPos:0}, {schemeEndPos:0});
    } catch(ex) { 
      alert(mzGetTextFromBundle('errorText'));
    }
    if (scheme == "http") {
      var checkURL = "http://validator.w3.org/check?uri=" + aURL + 
                     "&charset=%28detect+automatically%29&doctype=Inline";
      getBrowser().addTab(checkURL, null);
    }
    else {
      alert(mzGetTextFromBundle('unsupportedProtocolForValidator', [scheme]));
    }
  }
}
//////////////////////////////////////////////////////////////////////////
function handlePTFolders(node)
{
  if (!node.hasChildNodes())
    return; // no folder, bail out
  var personalToolbar = node.parentNode;
  // 'hbox' for folders and 'toolbox' for the Bookmarks button 
  if (personalToolbar.nodeName == "hbox")
    personalToolbar = personalToolbar.parentNode;
  if ("lastPopup" in personalToolbar && personalToolbar.lastPopup != null) {
    node = node.firstChild;
    if (node.nodeName == "menupopup") {
      if (personalToolbar.lastPopup != null)
        personalToolbar.lastPopup.hidePopup();
      node.showPopup(node);
    }
  }
}
//////////////////////////////////////////////////////////////////////////
function initViewMenu(aMenupopup)
{
  // XXX: Total HACK to remove the original menu items
  var i = 0;
  var removal = aMenupopup.getElementsByAttribute("observes", "cmd_viewpersonaltoolbar"); 

  initGoogleBoxMenuitem("GoogleBoxShowHideMenuitem");
  if (removal.length) {
    for (i = 0; i < removal.length; i++) {
      if (!removal[i].hasAttribute("acceltext"))
        aMenupopup.removeChild(removal[i]);
    }
  }
  removal = aMenupopup.getElementsByAttribute("observes", "cmd_viewnavbar");

  if (removal.length) {
    for (i = 0; i < removal.length; i++) {
      if (removal[i].getAttribute('id') != "navbarButtonPopup")
        aMenupopup.removeChild(removal[i]);
    }
  }
  initToolbarsMenu();
}
//////////////////////////////////////////////////////////////////////////
// The following five functions are GoogleBox specific functions
//////////////////////////////////////////////////////////////////////////
function aboutGooglebox()
{
  if (isGoogleBoxInstalled()) {
    alert(document.getElementById("internalToolBox").mVersionInfo);
  }
}
//////////////////////////////////////////////////////////////////////////
function isGoogleBoxInstalled(aStartupFlag)
{
  // We should also check the menu items in QPrefs Extension Manager!!!
  if (!mzToolbox.mToolboxActivated) {
    if (!aStartupFlag)
      gBrowser.selectedTab = gBrowser.addOrGetTab("http://multizilla.mozdev.org/features/googlebox.html");
    return false;
  }
  return true;
}
//////////////////////////////////////////////////////////////////////////
function initGoogleBoxMenuitem(aMenuitem)
{
  var enabled = mzPreferences.readMyPref('multizilla.integrated.toolbar', 'bool', false);

  if (!enabled || mzToolbox.mPlaceHolder.getAttribute("hidden") == "true" || 
      document.getElementById('MultiZillaToolbar').getAttribute('hidden') == "true")
    document.getElementById(aMenuitem).removeAttribute("checked");
  else
    document.getElementById(aMenuitem).setAttribute("checked", "true");
}
//////////////////////////////////////////////////////////////////////////
function toggleOrEnableGoogleBox(aStartupFlag)
{
  if (!isGoogleBoxInstalled(aStartupFlag))
    return;

  var checkboxText = null;
  var prefString = "multizilla.integrated.toolbar";
  var enabled = mzPreferences.readMyPref(prefString, 'bool', false);
  var notify = mzPreferences.readMyPref(prefString + "-notify", 'bool', true);

  if (!notify && aStartupFlag)
    return;

  if (!enabled) {
    var promptService = Components.classes['@mozilla.org/embedcomp/prompt-service;1']
                                  .getService(Components.interfaces.nsIPromptService);

    var title = mzGetTextFromBundle('mzWizard');
    var text = mzGetTextFromBundle('enableGoogleBoxText');
    var checkbox = {value:0};

    if (aStartupFlag)
      checkboxText = mzGetTextFromBundle('rememberDecisionText');

    var result = promptService.confirmEx(window, title, text, 
                                        (promptService.BUTTON_POS_0 * promptService.BUTTON_TITLE_YES) +
                                        (promptService.BUTTON_POS_1 * promptService.BUTTON_TITLE_NO),
                                         null, null, null, checkboxText, checkbox);

    if (checkbox.value) {
      mzPreferences.writePref('bool', prefString + "-notify", false);
      return;
    }
    if (result == 1)
      return;
    mzPreferences.writePref('bool', prefString, true);
    return;
  }
  updateGoogleBoxState(true, false);
  mzToolbox.refreshMultiZillaButtons();
}
//////////////////////////////////////////////////////////////////////////
function updateGoogleBoxState(aState, aSkipFlag)
{
  if (aState && document.getElementById('MultiZillaToolbar').getAttribute('hidden') == "true") {
    if (document.getElementById('internalToolBox').getAttribute('hidden') != "true") {
      goToggleToolbar('MultiZillaToolbar', 'cmd_viewMultiZillaToolbar');
      return;
    }
    goToggleToolbar('MultiZillaToolbar', 'cmd_viewMultiZillaToolbar');
  }
  if (!aSkipFlag)
    goToggleToolbar('internalToolBox', 'cmd_viewIntegratedToolBox')
}
//////////////////////////////////////////////////////////////////////////
function askToDisableButton(aEvent)
{
  aEvent.preventBubble();

  var button = aEvent.target;
  var buttonId = button.getAttribute("id");

  if (buttonId) {
    var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
                                  .getService(Components.interfaces.nsIPromptService);

    if (promptService.confirm(window, mzGetTextFromBundle("disableButtonTitle"), mzGetTextFromBundle("disableButtonText"))) {
      var index = buttonId.indexOf("-");
      var buttonName = buttonId.substring(0, index);
      var observerId = button.getAttribute("observes");

      if (observerId) {
         button.setAttribute("hidden", "true");
         /* var observer = document.getElementById(observerId);
         alert(observer); */
         // observer.setAttribute("disabled", true);
      }
      if (buttonId == "qpmenu-tbbutton" || buttonId == "clearlocbar-tbbutton")
        mzPreferences.writePref("bool", "multizilla.showbutton." + buttonName, false);
      else
        mzPreferences.writePref("bool", "browser.toolbars.showbutton." + buttonName, false);
    }
  }
}
//////////////////////////////////////////////////////////////////////////
function doHomeButtonClick(aEvent)
{
  /* BrowserHome() in navigator.js has been updated so now we can use:
  if (aEvent.button == 2)
    askToDisableButton(aEvent);
  else 
    BrowserHome(aEvent); */
  if (aEvent.button == 1) {
    var homePage = getHomePage();
    // We don't have to open a new tab for a group
    if (homePage.length == 1) { // single home page set?
      var tabbrowser = getBrowser();
      tabbrowser.selectedTab = tabbrowser.addTab();
    }
    BrowserHome();
  }
  else if (aEvent.button == 2)
    askToDisableButton(aEvent);
}
//////////////////////////////////////////////////////////////////////////
function initButtonContextMenu(aContextMenu, aID)
{
  var buttonIDs = (aID == "NT") ? [ "skip", "skip", "back-button", "forward-button", 
                                    "reload-button", "stop-button", "skip", 
                                    "qpmenu-tbbutton", "clearlocbar-tbbutton", 
                                    "skip", "go-button", "search-button", "print-button" ] : 
                                  [ "skip", "skip", "home-button", "bookmarks-button", 
                                    "qpmenu-button" ];

  for (var i = 0; i < buttonIDs.length; i++) {
    if (buttonIDs[i] != "skip") {
      var button = document.getElementById(buttonIDs[i]);
      var hidden = button.getAttribute("hidden");
      aContextMenu.childNodes[i].setAttribute("checked", (hidden == "true") ? "false" : "true");
    }
  }
  return;
}
//////////////////////////////////////////////////////////////////////////
function doButtonUpdate(aEvent)
{
  var buttonId = aEvent.getAttribute("buttonid");
  var index = buttonId.indexOf("-");
  var buttonName = buttonId.substring(0, index);

  if (buttonId == "qpmenu-tbbutton" || buttonId == "clearlocbar-tbbutton")
    mzPreferences.toggleBoolPref("multizilla.showbutton." + buttonName, "bool", true);
  else
    mzPreferences.toggleBoolPref("browser.toolbars.showbutton." + buttonName, "bool", true);
}
//////////////////////////////////////////////////////////////////////////
function overrideContextMenu(aEvent)
{
  if (aEvent.button == 2) {
    var contextMenu = aEvent.target.getAttribute("context-menu");
    var overrideContextPopup = document.getElementById("buttonContextPopup");
    var defaultContextPopup = document.getElementById(contextMenu);
    // Note that attribute popup="" is needed in order to open the context menu at the desired position!
    if (aEvent.ctrlKey) {
      if (defaultContextPopup)
        defaultContextPopup.hidePopup();
      overrideContextPopup.showPopup(overrideContextPopup, aEvent.clientX+2, aEvent.clientY+2, "popup", "at_pointer");
    }
    else if (contextMenu) {
      overrideContextPopup.hidePopup();
      defaultContextPopup.showPopup(defaultContextPopup, aEvent.clientX+2, aEvent.clientY+2, "popup", "at_pointer");
    }
  }
}
////////////////////////////////////////////////////////////////////////////////
function useFirstPage()
{
 var uriToLoad = null;
  if ("arguments" in window && window.arguments.length >= 1 && window.arguments[0])
    uriToLoad = window.arguments[0];
  if (mzPreferences.readMyPref("multizilla.tabs.blank-tab-first", "bool", true)) {
    if ((mzPreferences.readMyPref("browser.startup.page", "int", 1) == 1 && 
        getHomePage() == "about:blank" || getHomePage() == "") || uriToLoad == "about:blank" || 
        mzPreferences.readMyPref("browser.startup.page", "int", 0) == 3 && uriToLoad == "about:blank")
      return true;
  }
  return false;
}
//////////////////////////////////////////////////////////////////////////
function mzOnImageBlocked(aEvent)
{
  // dump("\nImage blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("image", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function mzObjectBlocked(aEvent)
{
  // dump("\nObject blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("object", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function mzOnScriptBlocked(aEvent)
{
  // dump("\nScript blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("script", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function mzOnFrameBlocked(aEvent)
{
  // dump("\nFrame blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("frame", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function mzOnDocumentBlocked(aEvent)
{
  // dump("\nDocument blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("document", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function mzMetaRedirectBlocked(aEvent)
{
  // dump("\nMeta Redirect blocked URL: " + aEvent.blockedURI);
  playSoundForBlocked("meta", addBlockedContentEntry(aEvent));
}
//////////////////////////////////////////////////////////////////////////
function addBlockedContentEntry(aEvent)
{
  var blockedContent, contentType;
  var browser = aEvent.browserElement;

  if (!browser) { // This should never happen but I like to get notify when it does!
    alert("Please notify bugs4hj@netscape.net when you see this!\n\nBrowser failed for:\n" + 
          "Content type: " + aEvent.type + "\nHostport: " + aEvent.requestingWindowURI.hostPort);
    return false;
  }
  if (browser.localName == undefined) { // Extra check added for Mozilla 1.7.5!
    dump("\nWARNING browser == " + browser.localName + " for: " + aEvent.blockedURI.hostPort);
    return true;
  }
  // 'browser' might be an image element for favicons!
  else if (browser.localName != "browser") { // && browser.id != undefined) {
    if (browser.id == "page-proxy-favicon")// location bar
      browser = gBrowser.mCurrentBrowser;
    if (browser.id == "tab-favicon") // tab
      browser = gBrowser.getBrowserForTab(browser.parentNode.parentNode.parentNode.parentNode);
  }

  switch(aEvent.type)
  {
    case "MZImageBlocked": 
         blockedContent = (browser.mBlockedContent.images == undefined) ? browser.mBlockedContent.images = new Array() : browser.mBlockedContent.images; 
         contentType = "image";
         break;
    case "MZObjectBlocked":
         blockedContent = (browser.mBlockedContent.objects == undefined) ? browser.mBlockedContent.objects = new Array() : browser.mBlockedContent.objects;
         contentType = "object";
         break;
    case "MZScriptBlocked":
         blockedContent = (browser.mBlockedContent.scripts == undefined) ? browser.mBlockedContent.scripts = new Array() : browser.mBlockedContent.scripts;
         contentType = "script";
         break;
    case "MZFrameBlocked":
         blockedContent = (browser.mBlockedContent.frames == undefined) ? browser.mBlockedContent.frames = new Array() : browser.mBlockedContent.frames;
         contentType = "frame";
         break;
    case "MZDocumentBlocked":
         blockedContent = (browser.mBlockedContent.documents == undefined) ? browser.mBlockedContent.documents = new Array() : browser.mBlockedContent.documents;
         contentType = "document";
         break;
    case "MZMetaRedirectBlocked":
         blockedContent = (browser.mBlockedContent.meta == undefined) ? browser.mBlockedContent.meta = new Array() : browser.mBlockedContent.meta;
         contentType = "meta";
         break;
    default: dump("\nUNSUPPORTED EVENT TYPE USED for 'addBlockedContentEntry()'");
  }
  var logType = mzPreferences.readMyPref("multizilla.content-blocker.log_enabled." + contentType, "int", 0)
  // 0 = logging disabled / 1 = add basic log entry (domain only) / 2 = add extended log entry (complete URL) 

  if (Boolean(logType)) {
    for (i in blockedContent) {
      if (blockedContent && blockedContent[i].filter && blockedContent[i].filter.match(aEvent.filter)) {
        // Yes, bail out early
        dump("\n" + contentType + " blocked by filter: " + aEvent.filter + " (previously matched)");
        blockedContent[i].counter++;
        return false;
      }
    }
    // var entryData = (logType == 1) ? aEvent.blockedURI.hostPort : aEvent.blockedURI.spec;
    var dataObject = new Object();
    dataObject.counter = blockedContent.length;
    dataObject.blockedURI = (logType == 1) ? aEvent.blockedURI.hostPort : aEvent.blockedURI.spec;
    dataObject.filter = aEvent.filter;
    blockedContent.push(dataObject);
    var index = blockedContent.length;
    dump("\nindex: " + index);
    /* dump("\nblockedContent[index].counter: " + blockedContent[index].counter);
    dump("\nblockedContent[index].blockedURI: " + blockedContent[index].blockedURI);
    dump("\nblockedContent[index].filter: " + blockedContent[index].filter); */

    if (blockedContent.length > 100)
      blockedContent.shift();

    // dump("\n" + blockedContent.length + " " + contentType + "(s) blocked - last match: " + aEvent.filter);
    dump("\n" + contentType + " blocked by filter: " + aEvent.filter + " (new match)" +
         "\nAdding filter to " + contentType + " log (" + blockedContent.length + " filter(s) logged)");
  }
  return true;
}
//////////////////////////////////////////////////////////////////////////
function playSoundForBlocked(aContentType, aNewEntry)
{
  var prefBranch = "multizilla.content-blocker.";
  var shouldPlaySound = mzPreferences.readMyPref(prefBranch + "sound_enabled." + aContentType, "int", 0)

  if (shouldPlaySound) {
    // Only play sound for new entries when sound filter is activated
    if (shouldPlaySound == 1 && aNewEntry == false)
      return; // No, bail out early for this duplicated entry
    var soundURL = mzPreferences.readMyPref(prefBranch + "sound_url." + aContentType, "char", "");
    mzPlaySound(soundURL);
  }
}
//////////////////////////////////////////////////////////////////////////
function mzPlaySound(aSoundURL)
{
  var _nsISound = Components.classes["@mozilla.org/sound;1"].createInstance(Components.interfaces.nsISound);

  if (!aSoundURL)
    _nsISound.beep();
  else  if (aSoundURL.indexOf("file://") == -1)
    _nsISound.playSystemSound(aSoundURL);
  else {
    var uri = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIURL);
    uri.spec = aSoundURL;
    var file = uri.file;

    if (file.exists)
      _nsISound.play(uri);
  } 
}
//////////////////////////////////////////////////////////////////////////
// We need to get notified of blocked popup windows. We replace mozilla's 
// 'DOMPopupBlocked' event listener (onPopupBlocked) with our event 
// listener. We call 'onPopupBlocked' when we're done.
//////////////////////////////////////////////////////////////////////////
function mzOnPopupBlocked(aEvent)
{
  var newPopupWindow = true;
  var browser = getBrowserForDocument(aEvent.target);

  if (!browser.mBlockedWindows)
    browser.mBlockedWindows = new Array();

  browser.mNumberOfBlockedWindows++;

  for (i in browser.mBlockedWindows) {
    if (browser.mBlockedWindows[i].popupWindowURI.spec == aEvent.popupWindowURI.spec) {
      browser.mBlockedWindows[i].blockedCounter++;
      newPopupWindow = false;
    }
  }
  if (newPopupWindow) {
    var obj = { requestingWindowURI: aEvent.requestingWindowURI,
                popupWindowName: aEvent.popupWindowName,
                popupWindowURI: aEvent.popupWindowURI,
                popupWindowFeatures: aEvent.popupWindowFeatures,
                blockedCounter: 1
              };
    browser.mBlockedWindows.push(obj);
  }
  gPopupBlockerObserver.onUpdatePageReport(browser);

  // Do we need to display the popup icon on the tab?
  if (gPopupIconOnTab && gDelayedPopupIconRemoval > 0) {
    var tabbrowser = getBrowser();
    var targetTab = tabbrowser.getTabForBrowser(browser);
    targetTab.setAttribute("popupwindow", "true");
    tabbrowser.mzPopupIconCheck(aEvent.requestingWindowURI.spec, targetTab);
  }
}
//////////////////////////////////////////////////////////////////////////
// This is a replacement for the same function in navigator.js because we 
// are only interested in popup sound and we do not show the popup icon!
//////////////////////////////////////////////////////////////////////////
function onPopupBlocked(aEvent)
{
  var playSound = pref.getBoolPref("privacy.popups.sound_enabled");

  if (playSound) {
    var soundURL = pref.getCharPref("privacy.popups.sound_url");
    mzPlaySound(soundURL);
  }
}
//////////////////////////////////////////////////////////////////////////
// This updates the number of blocked windows in the tooltip
//////////////////////////////////////////////////////////////////////////
function isHostBlocked(aBrowser, aHost)
{
  for (i in aBrowser.mBlockedWindows) {
    if (aBrowser.mBlockedWindows[i].hostPort == aHost)
      return true;
  }
  return false;
}
//////////////////////////////////////////////////////////////////////////
function toJavaScriptConsole() {
  toOpenWindowByType("global:console", "chrome://multiviews/content/js-console/console.xul");
}

function togglePermission(aEvent)
{
  var property = aEvent.target.id.replace(/-\w*/, '');
  var tabbrowser = getBrowser();
  var value = (aEvent.target.getAttribute('blocked') == 'true') ? 'false' : 'true';
  tabbrowser.toggleDocShellProperty(tabbrowser.mCurrentTab, property, value);
  aEvent.target.setAttribute('blocked', value);
  tabbrowser.reloadTab(tabbrowser.mCurrentTab, false);
}

function chromeTest()
{
  var chromeDS = getNewOrCurrentDSByFilename("chrometest.rdf", false, null, false);
  alert("chromeDS: " + chromeDS);
  var prefTree = "chrome://communicator/content/pref/preftree.xul";
  var prefOverlay = "chrome://multiviews/content/pref/multiviewsPrefOverlay.xul";
  var result = checkResourceForValue(chromeDS, prefTree, prefOverlay)
  alert("result: " + result);
}